@@ -9,9 +9,7 @@ from django.http  import  HttpResponseRedirect
 from django.contrib.sessions.middleware import SessionMiddleware
 # Obscure the session id when passing it around in HTML
 from cookieless.utils import CryptSession
-
-LINKS_RE = r'<a(?P<pre_href>[^>]*?)href=["\'](?P<in_href>[^"\']*?)(?P<anchor>#\S+)?["\'](?P<post_href>[^>]*?)>'
-
+from cookieless.config import LINKS_RE, DEFAULT_SETTINGS
 
 class CookielessSessionMiddleware(object):
     """ Django snippets julio carlos and Ivscar 
@@ -29,47 +27,83 @@ class CookielessSessionMiddleware(object):
         """ Add regex for auto inserts and an instance of
             the standard django.contrib.sessions middleware
         """
+        self.settings = getattr(settings, 'COOKIELESS', DEFAULT_SETTINGS)
         self._re_links = re.compile(LINKS_RE, re.I)
         self._re_forms = re.compile('</form>', re.I)
         self._sesh = CryptSession()
         self.standard_session = SessionMiddleware()
+        self.engine = import_module(settings.SESSION_ENGINE)
+
 
     def process_request(self, request):
         """ Check if we have the session key from a cookie, 
             if not check post, and get if allowed
-            If decryption fails will not return unicode key so
-            test for that and set to empty string
+            If decryption fails 
+            (ie secret is wrong because of other setting restrictions)
+            decrypt may not return a real key so
+            test for that and start a new session if so
+            NB: Cant check for no_cookies attribute of request here since 
+                its before it gets sent to the view
         """
         name = settings.SESSION_COOKIE_NAME
-        session_key = request.COOKIES.get(name, '')
-        if not session_key:
+        session_key = self._sesh.decrypt(request, 
+                                         request.POST.get(name, None))
+        if not session_key and self.settings.get('USE_GET', False):
             session_key = self._sesh.decrypt(request, 
-                                        request.POST.get(name, None))
-            if not session_key and getattr(settings, 'COOKIELESS_USE_GET', False):
-                session_key = self._sesh.decrypt(request, 
-                                            request.GET.get(name, ''))
-            try:
-                session_key = unicode(session_key)
-            except:
-                session_key = ''
-        engine = import_module(settings.SESSION_ENGINE)
-        request.session = engine.SessionStore(session_key)
+                                             request.GET.get(name, ''))
+        if not session_key:
+            session_key = request.COOKIES.get(name, '')
+
+        try:
+            request.session = self.engine.SessionStore(session_key)
+        except:
+            pass
+        # NB: engine may work but return empty key less session
+        try:
+            session_key = request.session.session_key
+        except:
+            session_key = ''
+        # If the session_key isn't tied to a session - create a new one
+        if not session_key:
+            request.session = self.engine.SessionStore() 
+            request.session.save()
 
     def process_response(self, request, response):
         """
         Copied from contrib.session.middleware with no_cookies switch added ...
         If request.session was modified, or if the configuration is to save the
         session every time, save the changes and set a session cookie.
+        NB: request.COOKIES are the sent ones and response.cookies the set ones!
         """
         if getattr(request, 'no_cookies', False):
-            if getattr(settings, 'COOKIELESS_ANON_ONLY', 
-                       False) and not request.user.is_anonymous():
+            # The django test client has mock session / cookies which assume cookies are in use
+            # so to turn off cookieless for tests 
+            # TODO: Find work around for test browser switch hardcoded to session being from django.contrib.session 
+            if request.META.get('SERVER_NAME', '') == 'testserver':
                 return self.standard_session.process_response(request, response)
+            
+            if request.COOKIES:
+                if self.settings.get('NO_COOKIE_PERSIST', False):
+                    # Don't persist a session with cookieless for any session 
+                    # thats been set against a cookie 
+                    # - may be attached to a user - so always start a new separate one
+                    cookie_key = request.COOKIES.get(settings.SESSION_COOKIE_NAME, '')
+                    if cookie_key == request.session.session_key:
+                        request.session = self.engine.SessionStore() 
+                        request.session.save()
+
+                # Blat any existing cookies
+                for key in request.COOKIES.keys():
+                    response.delete_cookie(key)
+
+            # Dont set any new cookies
             response.cookies.clear()
+
             # cookieless - do same as standard process response
             #              but dont set the cookie
-            if getattr(settings, 'COOKIELESS_REWRITE', False):
+            if self.settings.get('REWRITE', False):
                 response = self.nocookies_response(request, response)
+
             try:
                 accessed = request.session.accessed
                 modified = request.session.modified
@@ -120,7 +154,7 @@ class CookielessSessionMiddleware(object):
                                  )
                 return return_str                                 
 
-            if getattr(settings, 'COOKIELESS_USE_GET', False):            
+            if self.settings.get('USE_GET', False):            
                 try:
                     response.content = self._re_links.sub(new_url, response.content)
                 except:
